@@ -30,12 +30,6 @@ OtherClass = function() {
 };
 
 
-/**
- * Prevent renaming of class. Needed for reflection.
- */
-goog.exportSymbol('OtherClass', OtherClass);
-
-
 /**
  * Metadata
  *
@@ -52,8 +46,6 @@ OtherClass.prototype.ROYALE_CLASS_INFO = { names: [{ name: 'OtherClass', qName:
  */
 OtherClass.prototype.ROYALE_REFLECTION_INFO = function () {
   return {
-    variables: function () {return {};},
-    accessors: function () {return {};},
     methods: function () {
       return {
         'OtherClass': { type: '', declaredBy: 'OtherClass'}
@@ -62,8 +54,7 @@ OtherClass.prototype.ROYALE_REFLECTION_INFO = function () {
   };
 };
 /**
- * @export
  * @const
  * @type {number}
  */
-OtherClass.prototype.ROYALE_REFLECTION_INFO.compileFlags = 9;
+OtherClass.prototype.ROYALE_COMPILE_FLAGS = 9;
